OC.L10N.register(
    "settings",
    {
    "Couldn't send reset email. Please contact your administrator." : "Die E-Mail zum Zurücksetzen konnte nicht versendet werden. Bitte kontaktiere Deinen Administrator.",
    "Email sent" : "E-Mail wurde verschickt",
    "__language_name__" : "Deutsch (Österreich)",
    "Invalid request" : "Fehlerhafte Anfrage",
    "Delete" : "Löschen",
    "Very weak password" : "Sehr schwaches Passwort",
    "Weak password" : "Schwaches Passwort",
    "So-so password" : "Durchschnittliches Passwort",
    "Good password" : "Gutes Passwort",
    "Strong password" : "Starkes Passwort",
    "never" : "niemals",
    "Cheers!" : "Noch einen schönen Tag!",
    "Server address" : "Adresse des Servers",
    "Port" : "Port",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Insbesondere bei Nutzung des Desktop Clients zur Dateisynchronisierung wird vom Einsatz von SQLite abgeraten.",
    "Cancel" : "Abbrechen",
    "Email" : "E-Mail",
    "Password" : "Passwort",
    "New password" : "Neues Passwort",
    "Change password" : "Passwort ändern",
    "Name" : "Name",
    "Username" : "Benutzername",
    "Personal" : "Persönlich",
    "Admin" : "Administration",
    "Error" : "Fehler",
    "Other" : "Anderes",
    "Share" : "Teilen",
    "Add" : "Hinzufügen"
},
"nplurals=2; plural=(n != 1);");
